/**
 * An interface for the FileSystem.
 */

#ifndef FILESYSTEM_H_
#define FILESYSTEM_H_

#include <string>

#include <boost/filesystem.hpp>

/**
 * The class that manages the FileSystem.
 *
 * This class uses the path of the program to get the root path of the
 * game, assuming that the executable file is in a subdirectory.
 */
class FileSystem {
public:
	static FileSystem &getSingleton();
	static FileSystem *getSingletonPtr();

	void fromArguments(int argc, char **argv);

	const boost::filesystem::path &appRoot();

private:
	FileSystem();

	boost::filesystem::path osDependent();

	// The levels to go up from the executable path
	const static int LEVELS = 2;

	static FileSystem *msSingleton;

	int mArgc;
	char **mArgv;

	std::string mFromArgs;
	boost::filesystem::path mPath;
};

#endif /* FILESYSTEM_H_ */
